#
# spec file for package ImageMagick
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ImageMagick

BuildRequires:  autoconf >= 2.69
BuildRequires:  dcraw
%if 0%{?suse_version} >= 1140
BuildRequires:  dejavu-fonts
%endif
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  ghostscript-devel
BuildRequires:  libbz2-devel
BuildRequires:  libdjvulibre-devel
BuildRequires:  libexif-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjbig-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
%if 0%{?suse_version} >= 1140
BuildRequires:  liblqr-devel
%endif
BuildRequires:  librsvg-devel
BuildRequires:  libtiff-devel >= 4.0.3
BuildRequires:  libtool
BuildRequires:  libwebp-devel
BuildRequires:  libwmf-devel
BuildRequires:  libxml2-devel
BuildRequires:  lzma-devel
%if 0%{?suse_version} >= 1310
BuildRequires:  mupdf-devel-static
%endif
%if 0%{?suse_version} >= 1140
BuildRequires:  openexr-devel
%endif
BuildRequires:  openjpeg2-devel >= 2.1.0
%if 0%{?suse_version} >= 1140
BuildRequires:  p7zip
%endif
BuildRequires:  pango-devel
BuildRequires:  pkgconfig
BuildRequires:  xdg-utils
BuildRequires:  xz
BuildRequires:  zip

%define maj           6
%define mfr_version   %{maj}.9.1
%define mfr_revision  10
%define quantum_depth 16
%define source_version %{mfr_version}-%{mfr_revision}
%define clibver   2
%define cxxlibver 6
%define libspec -%{maj}_Q%{quantum_depth}
Version:        %{mfr_version}.%{mfr_revision}
Release:        1.2
Summary:        Viewer and Converter for Images
License:        ImageMagick
Group:          Productivity/Graphics/Other
Url:            http://www.imagemagick.org
Source:         http://www.imagemagick.org/download/releases/ImageMagick-%{mfr_version}-%{mfr_revision}.tar.xz
# To get mtime of file
Source1:        ImageMagick.changes
Source2:        baselibs.conf
Source3:        http://www.imagemagick.org/download/releases/ImageMagick-%{mfr_version}-%{mfr_revision}.tar.xz.asc
Source4:        ImageMagick.keyring
# suse specific patches
Patch0:         ImageMagick-6.6.8.9-examples.patch
Patch1:         ImageMagick-6.6.8.9-doc.patch
Patch2:         ImageMagick-6.7.6.1-no-dist-lzip.patch
Patch3:         ImageMagick-6.8.4.0-rpath.patch
# workaround for http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=23462
# upstream insists on XPMCompliance, so leaving this for compatibility reasons
Patch4:         ImageMagick-6.8.5.7-no-XPMCompliance.patch
# bugs
# will ask upstream if needed, or if other solution exists
Patch11:        ImageMagick-6.8.4.0-dont-build-in-install.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%package -n perl-PerlMagick
Requires:       ImageMagick = %{version}
Requires:       libMagickCore%{libspec}-%{clibver} = %{version}
Requires:       perl = %{perl_version}
Summary:        Perl interface for ImageMagick
Group:          Development/Libraries/Perl

%package devel
Requires:       ImageMagick = %{version}
Requires:       libMagickCore%{libspec}-%{clibver} = %{version}
Requires:       libMagickWand%{libspec}-%{clibver} = %{version}
Summary:        Include Files and Libraries Mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
# bnc#741947:
Requires:       libbz2-devel

%package extra
Requires:       ImageMagick = %{version}
Requires:       libMagickCore%{libspec}-%{clibver} = %{version}
Summary:        Viewer and Converter for Images - extra codecs
Group:          Productivity/Graphics/Other
#delegates configured in delegates.xml that imagemagick can use
Recommends:     autotrace dcraw transfig ghostscript_any hp2xx netpbm ghostpcl libwmf

%package -n libMagickCore%{libspec}-%{clibver}
Summary:        Viewer and Converter for Images - runtime library
Group:          Productivity/Graphics/Other
Suggests:       ImageMagick-extra = %{version}

%package -n libMagickWand%{libspec}-%{clibver}
Summary:        Viewer and Converter for Images - runtime library
Group:          Productivity/Graphics/Other

%package -n libMagick++%{libspec}-%{cxxlibver}
Requires:       ImageMagick
Summary:        C++ Interface for ImageMagick - runtime library
Group:          Development/Libraries/C and C++

%package -n libMagick++-devel
Requires:       ImageMagick-devel = %{version}
Requires:       libMagick++%{libspec}-%{cxxlibver} = %{version}
Requires:       libstdc++-devel
Summary:        C++ Interface for ImageMagick - files mandatory for development
Group:          Development/Libraries/C and C++

%package doc
Summary:        Document Files for ImageMagick Library
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description
ImageMagick is a robust collection of tools and libraries to read,
write, and manipulate an image in many image formats, including popular
formats like TIFF, JPEG, PNG, PDF, PhotoCD, and GIF. With ImageMagick,
you can create images dynamically, making it suitable for Web
applications. You can also resize, rotate, sharpen, color-reduce, or
add special effects to an image and save your completed work in many
different image formats. Image processing operations are available from
the command line as well as through C, C++, and PERL-based programming
interfaces.

%description devel
ImageMagick is a robust collection of tools and libraries to read,
write, and manipulate an image in many image formats, including popular
formats like TIFF, JPEG, PNG, PDF, PhotoCD, and GIF. With ImageMagick,
you can create images dynamically, making it suitable for Web
applications. You can also resize, rotate, sharpen, color-reduce, or
add special effects to an image and save your completed work in many
different image formats. Image processing operations are available from
the command line as well as through C, C++, and PERL-based programming
interfaces.

%description extra
This package adds support for djvu, wmf and jpeg2000 formats and
installs optional helper applications.

ImageMagick is a robust collection of tools and libraries to read,
write, and manipulate an image in many image formats, including popular
formats like TIFF, JPEG, PNG, PDF, PhotoCD, and GIF. With ImageMagick,
you can create images dynamically, making it suitable for Web
applications. You can also resize, rotate, sharpen, color-reduce, or
add special effects to an image and save your completed work in many
different image formats. Image processing operations are available from
the command line as well as through C, C++, and PERL-based programming
interfaces.

%description -n libMagickCore%{libspec}-%{clibver}
ImageMagick is a robust collection of tools and libraries to read,
write, and manipulate an image in many image formats, including popular
formats like TIFF, JPEG, PNG, PDF, PhotoCD, and GIF. With ImageMagick,
you can create images dynamically, making it suitable for Web
applications. You can also resize, rotate, sharpen, color-reduce, or
add special effects to an image and save your completed work in many
different image formats. Image processing operations are available from
the command line as well as through C, C++, and PERL-based programming
interfaces.

%description -n libMagickWand%{libspec}-%{clibver}
ImageMagick is a robust collection of tools and libraries to read,
write, and manipulate an image in many image formats, including popular
formats like TIFF, JPEG, PNG, PDF, PhotoCD, and GIF. With ImageMagick,
you can create images dynamically, making it suitable for Web
applications. You can also resize, rotate, sharpen, color-reduce, or
add special effects to an image and save your completed work in many
different image formats. Image processing operations are available from
the command line as well as through C, C++, and PERL-based programming
interfaces.

%description -n perl-PerlMagick
PerlMagick is an objected-oriented Perl interface to ImageMagick. Use
the module to read, manipulate, or write an image or image sequence
from within a Perl script. This makes it suitable for Web CGI scripts.

%description -n libMagick++%{libspec}-%{cxxlibver}
This is Magick++, the object-oriented C++ API for the ImageMagick
image-processing library.

Magick++ supports an object model inspired by PerlMagick. Magick++
should be faster than PerlMagick since it is written in a compiled
language which is not parsed at run-time. This makes it suitable for
Web CGI programs. Images support implicit reference counting so that
copy constructors and assignment incur almost no cost. The cost of
actually copying an image (if necessary) is done just before
modification and this copy is managed automatically by Magick++.
De-referenced copies are automatically deleted. The image objects
support value (rather than pointer) semantics so it is trivial to
support multiple generations of an image in memory at one time.

%description -n libMagick++-devel
This is Magick++, the object-oriented C++ API for the ImageMagick
image-processing library.

Magick++ supports an object model inspired by PerlMagick. Magick++
should be faster than PerlMagick since it is written in a compiled
language which is not parsed at run-time. This makes it suitable for
Web CGI programs. Images support implicit reference counting so that
copy constructors and assignment incur almost no cost. The cost of
actually copying an image (if necessary) is done just before
modification and this copy is managed automatically by Magick++.
De-referenced copies are automatically deleted. The image objects
support value (rather than pointer) semantics so it is trivial to
support multiple generations of an image in memory at one time.

%description doc
HTML documentation for ImageMagick library and scene examples.

%prep
%setup -q -n ImageMagick-%{source_version}
%patch0
%patch1
%patch2
%patch3  -p1
%patch4  -p1
%patch11 -p1

# remove executeable bits from per demos
chmod -x PerlMagick/demo/*.pl

%build
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="-L%{_libdir}"
# for MODULES_DIRNAME setup purpose see bnc#866442
export MODULES_DIRNAME="modules-%{maj}_Q%{quantum_depth}-%{clibver}"
# for SHAREARCH_DIRNAME setup purpose see bnc#866442
export SHAREARCH_DIRNAME="config-%{maj}_Q%{quantum_depth}-%{clibver}"
# for CONFIGURE_RELATIVE_PATH setup purpose see bnc#866442
sed -i 's:^\(CONFIGURE_RELATIVE_PATH=.*\):\1_Q%{quantum_depth}-%{clibver}:' configure.ac
CHANGES=`stat --format="%y" %SOURCE1|cut --characters=1-10`
# Use mtime of .changes for build time
sed -i -e "s|^PACKAGE_RELEASE_DATE.*$|PACKAGE_RELEASE_DATE=\"$CHANGES\"|" version.sh
autoreconf --force --install -v
automake
%configure --with-pic \
  --enable-shared \
  --without-frozenpaths \
  --with-magick_plus_plus \
  --with-modules \
  --with-threads \
  --with-perl \
  --with-perl-options="INSTALLDIRS=vendor CC='%__cc -L$PWD/magick/.libs' LDDLFLAGS='-shared -L$PWD/magick/.libs'" \
  --disable-static \
  --with-graphviz \
  --with-djvu \
  --with-lcms2 \
  --with-jbig \
  --with-openjp2 \
%if 0%{?suse_version} >= 1140
  --with-openexr \
%endif
  --with-rsvg \
  --with-webp \
  --with-wmf \
  --with-quantum-depth=%{quantum_depth} \
  --without-gcc-arch
# don't build together, PerlMagick could be miscompiled when using parallel build[1]
# [1] http://pkgs.fedoraproject.org/cgit/ImageMagick.git/tree/ImageMagick.spec
make %{?_smp_mflags} all
make -j1 perl-build

%if 0%{?suse_version} >= 1140
%check
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$PWD/magick/.libs:$PWD/wand/.libs
export MAGICK_CODER_MODULE_PATH=$PWD/coders/.libs
export MAGICK_CODER_FILTER_PATH=$PWD/filters/.libs
export MAGICK_CONFIGURE_PATH=$PWD/config
cd PerlMagick
make test
%endif

%install
%{__make} install \
     DESTDIR=%{buildroot} \
     pkgdocdir=%{_defaultdocdir}/%{name}/
%perl_process_packlist
cd 'Magick++'
  %{__rm} -rf demo/{.deps,.libs,*.C,*.o,Makefile*,run_demos.bat} 
  PATH='/bin:/usr/bin' find demo -type f -perm /111 -execdir %{__rm} -rf '{}' ';'
  %{__mv} demo/makefile.2 demo/Makefile
cd ..
%{__mv} -t %{buildroot}%{_sysconfdir}/%{name}* %{buildroot}%{_datadir}/%{name}*/*.xml  
PATH='/bin:/usr/bin' find %{buildroot}/%{_libdir} -name "*.la" ! -empty \
 -execdir %{__sed} -i -e 's@ -L/usr/src[^ ]*@@g' -e 's@ /usr/lib/libltdl.la@@g' '{}' ';'
%{__rm} %{buildroot}%{_libdir}/*.la

#remove duplicates
%if 0%{?suse_version} > 1020
%fdupes -s %{buildroot}%{_defaultdocdir}/%{name}
%fdupes -s %{buildroot}%{_includedir}/%{name}-%{maj}
%fdupes -s %{buildroot}%{_libdir}/pkgconfig
%endif

%post -n libMagickCore%{libspec}-%{clibver} -p /sbin/ldconfig

%postun -n libMagickCore%{libspec}-%{clibver} -p /sbin/ldconfig

%post -n libMagickWand%{libspec}-%{clibver} -p /sbin/ldconfig

%postun -n libMagickWand%{libspec}-%{clibver} -p /sbin/ldconfig

%post -n libMagick++%{libspec}-%{cxxlibver} -p /sbin/ldconfig

%postun -n libMagick++%{libspec}-%{cxxlibver} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/[^MW]*
%doc %{_mandir}/man1/*
%exclude %{_mandir}/man1/*-config.1.gz

%files -n libMagickCore%{libspec}-%{clibver}
%defattr(-,root,root)
%doc LICENSE
%dir %{_sysconfdir}/ImageMagick*
%config %{_sysconfdir}/ImageMagick*/*
%{_libdir}/libMagickCore*.so.%{clibver}*
%dir %{_libdir}/ImageMagick*
%dir %{_libdir}/ImageMagick*/modules*
%dir %{_libdir}/ImageMagick*/modules*/*
%exclude %{_libdir}/ImageMagick*/modules*/*/wmf.*
%exclude %{_libdir}/ImageMagick*/modules*/*/jp2.*
%exclude %{_libdir}/ImageMagick*/modules*/*/djvu.*
%{_libdir}/ImageMagick*/modules*/*/*.so
# don't remove la files, see bnc#579798
%{_libdir}/ImageMagick*/modules*/*/*.la
%{_libdir}/ImageMagick*/config*

%files -n libMagickWand%{libspec}-%{clibver}
%defattr(-,root,root)
%{_libdir}/libMagickWand*.so.%{clibver}*

%files extra
%defattr(-,root,root)
%{_libdir}/ImageMagick*/modules*/*/wmf.so
# don't remove la files, see bnc#579798
%{_libdir}/ImageMagick*/modules*/*/wmf.la
%{_libdir}/ImageMagick*/modules*/*/jp2.so
%{_libdir}/ImageMagick*/modules*/*/jp2.la
%{_libdir}/ImageMagick*/modules*/*/djvu.so
%{_libdir}/ImageMagick*/modules*/*/djvu.la

%files devel
%defattr(-,root,root)
%{_libdir}/libMagickCore*.so
%{_libdir}/libMagickWand*.so
%dir %{_includedir}/ImageMagick*
%{_includedir}/ImageMagick*/magick
%{_includedir}/ImageMagick*/wand
%{_bindir}/MagickCore-config
%{_bindir}/MagickWand-config
%{_bindir}/Magick-config
%{_bindir}/Wand-config
%{_libdir}/pkgconfig/MagickCore*.pc
%{_libdir}/pkgconfig/ImageMagick.pc
%{_libdir}/pkgconfig/ImageMagick-*.pc
%{_libdir}/pkgconfig/*Wand*.pc
%doc %{_mandir}/man1/*-config.1.gz
%exclude %{_mandir}/man1/Magick++-config.1.gz

%files -n perl-PerlMagick
%defattr(-,root,root,-)
%doc PerlMagick/README.txt
%doc PerlMagick/demo
%doc %{_mandir}/man3/*
%{perl_vendorarch}/auto/Image
%{perl_vendorarch}/Image
%if 0%{?suse_version} < 1140
/var/adm/perl-modules/ImageMagick
%endif

%files -n libMagick++%{libspec}-%{cxxlibver}
%defattr(-,root,root)
%{_libdir}/libMagick++*.so.%{cxxlibver}*

%files -n libMagick++-devel
%defattr(-,root,root)
%doc Magick++/demo
%doc Magick++/NEWS Magick++/README Magick++/AUTHORS
%{_libdir}/libMagick++*.so
%{_includedir}/ImageMagick*/Magick++.h
%{_includedir}/ImageMagick*/Magick++
%{_bindir}/Magick++-config
%{_libdir}/pkgconfig/ImageMagick++*.pc
%{_libdir}/pkgconfig/Magick++*.pc
%doc %{_mandir}/man1/Magick++-config.1.gz

%files doc
%defattr(-,root,root)
%{_defaultdocdir}/%{name}

%changelog
* Mon Jul 27 2015 sbrabec@suse.com
- Update to 6.9.1-10:
  * New version 6.9.1-10, SVN revision 19269.
  * coders/magick.c: added "-define h:format=FMT" and
    "-define magick:format=FMT" options. FMT can be any output format
    supported by ImageMagick except "H" or "MAGICK". If this define is
    omitted, the encoder uses GIF by default for pseudoclass images and
    PNM for directclass images, as previously.  Made "MAGICK" (read-write)
    and "H" (write-only) visible in the format list.
  * Removed incorrect EOF check in the DDS reader (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=28065).
  * Fixed undefined behaviors (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=28067).
  * Return exception message for unknown image properties.
  * Color shift removed when reading transparent gray images (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=28081)
* Thu Jul 23 2015 jweberhofer@weberhofer.at
- Removed duplicates
- Only libMagickCore and ImageMagick-doc contains the LICENSE file. Other
  libraries do not longer contain it, as they always require libMagickCore
  to be instaleld.
- Moved documentation to the ImageMagick-doc package.
- Removed executable bits from perl documentation-examples
- Added configurations for:
  * graphviz
  * lcms2 (Little CMS 2 color management)
  * jbig
  * openjp2 (JPEG 2000)
  * openexr
  * webp
- update to 6.9.1-9
  * Fixed issue with radial gradient in MVG (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27995).
- update to 6.9.1-8
  * New version 6.9.1-8, SVN revision 19167.
  * Correct install location of the Magick++ headers (reference
    https://github.com/ImageMagick/ImageMagick/pull/17/commits).
  * Different gif cropping behavior between versions (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=28013).
  * Cannot read properly simple psd file (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=28002).
- update to 6.9.1-7
  * Fixed and escaped output of the json coder. (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&p=27894).
  * Support BPG image format (respects -quality option).
  * A bordered transparent image now remains transparent (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=5&t=27937).
  * The -update option behavior restored (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=1&t=27939).
* Wed Jul  1 2015 jweberhofer@weberhofer.at
- update to 6.9.1-6
  * Cache cloning on disk optimized with sendfile() (if available).
  * Add an additional check for end-of-file for the RLE coder (reference
    http://www.imagemagick.org/discourse-server/viewforum.php?f=3&t=27870).
  * Respect resource limits in AVS coder.
  * Reverted change to 6.9.1-3 that skipped palette-building.
- update to 6.9.1-5
  * Use correct scale when interpretting alpha (e.g. rgba(0,0,0,1)).
  * DrawGetVectorGraphics() now returns proper XML (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27751).
  * Support writing EXR files with different color types (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=2&t=27759).
  * Prefer PKG_CHECK_MODULES() when searching for delegate libraries.
  * Throw exception if frame option bevel exceeds to the image width / height.
  * Resolve undefined behaviors (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27811).
- update to 6.9.1-4
  * Support 'restrict' keyword under Windows.
  * Added support for reading a user supplied layer mask in PSD files.
  * Added support for reading photoshop layers in TIFF files.
- update to 6.9.1-3
  * Fixed transparency issue with 16-bit tga files (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27469).
  * Fixed writing label and comment in tiff images (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=25516).
  * Jpeg images no longer have pixels per inch as a default value for density
    units when the density is not set (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27589).
  * Added support for setting the font color with -fill to the pango coder.
  * Fixed bug with "-define png:format=x" in png.c, introduced in version
    6.8.9-0, that caused the define to be ignored.
  * Replaced some dead code in ReadJNGImage with an assert().
  * Avoid palette-building when writing a grayscale PNG (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27580).
  * Support -define compose:clamp=false option (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=26946).
  * Don't extend any user supplied image buffer in SeekBlob() (bug report
    from a.chernij@corp...).
  * Improved reproducible builds (reference
    https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=783933).
  * Draw a rectangle of width & height of 1 (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=24874).
- update to 6.9.1-2
  * Avoid using a NULL alpha_image or color_image in the JNG decoder.
  * Fix JPEG-2000 transparency on write (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27304).
  * Identify now identifies PSD (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=26948).
  * Speed up writing to TGA (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27369).
  * Reduce draw epsilon to increase mathematical stability.
  * Fixed UTF8 issue when determining the current working directory
    on Windows (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=27295).
* Mon May 11 2015 pgajdos@suse.com
- update to 6.9.1-1
  * Skip empty frames when comparing layers.
  * Grayscale DPX image files are no longer skewed.
  * Fix integer overflow when scaling a 1-bit sample to Q64.
  * Account for differences in image size when comparing two images.
  * Set an upper ceiling compression with -quality and jpeg:extent.
* Mon Mar  2 2015 pgajdos@suse.com
- update to 6.9.0-9
  * Writing histograms / mpeg working again.
  * The -linear-stretch option worked for Q16 but not Q32.
* Thu Feb 26 2015 pgajdos@suse.com
- update to 6.9.0-7
  * Line strokes appeared too thin.
  * Keep text in caption area.
  * A transient bug for the write MSL element.
  * Fixed infinite loop in HDR reader.
  * In the PNG codec, check status wherever a function returns it.
  * Check lengths of certain MNG chunks before reading them.
  * Small optimization to pixel cache.
  * Additional coder sanity checks.
  etc. see ChangeLog
* Fri Jan 16 2015 pgajdos@suse.com
- update to 6.9.0-3
  * Don't read beyond the end of a tEXt keyword when checking for
    Raw profile.
  * Fixed enabling alpha in 32-bit BMP files.
  * Added support for writing 16-bit TGA files.
  * Improved performance of dds.
  * Fix ImageMagick crashes while read EXIF from TIFF.
  * Don't handle a "previous" image in the PNG or JNG decoder.
  * Don't override gamma with 1.0 when reading a grayscale PNG
    image.
  * Update progress monitor for every PNG row instead of every pass.
  * Reject input PNG with dimensions larger than specified with
  - limit width and -limit height.
  * etc., see ChangeLog
* Mon Dec 15 2014 pgajdos@suse.com
- do not use -march/-mtune [bnc#904545]
* Tue Nov 18 2014 pgajdos@suse.com
- update to 6.9.0-0
  * Check for zero-sized rendered SVG image.
  * EXIF directory offsets must be greater than 0.
  * Accept morphology kernels from files.
  * Don't optimize JPEG compression by default.
  * etc. see ChangeLog
* Thu Oct 30 2014 pgajdos@suse.com
- update to 6.8.9-8
  * Added sixel coder.
  * Fixed buffer overflow in PCX and DCM coder.
  * Added support for reading/writing the tIME chunk in the PNG coder.
  * Added eps:fit-page option to the PS coder to set -dEPSFitPage.
  * Support xyY colorspace.
  * Reduce noise while preserving edges with the -kuwahara option.
  * Off-by-one count when parsing an 8BIM profile.
  * OpenCL no longer benchmarks are run on every initialization.
  * Don't clone a 0x0 image.
* Mon Sep 22 2014 pgajdos@suse.com
- update to 6.8.9-8
  * JPEG library version >= 80 is thread safe
  * Added support for some legacy dds formats
* Wed Sep 10 2014 pgajdos@suse.com
- updated to 6.8.9-7
  * Fix off by one buglet when extracting profiles 8BIM.
  * Fixed bug when reading 1 bit PSD.
  * Fixed fill-rule in SVG clip path.
  * Added support for R5G6B5, RGB5A1 and RGBA4 dds files.
  * Write LAB pixels as percentages in the TXT image format.
  * Throw exception when image morphology differs when comparing.
  * Remove mogrify backup file.
  * Read WEBP images from STDIN.
* Mon Sep  8 2014 coolo@suse.com
- fix baselibs.conf requires for ImageMagick++
* Fri Aug 29 2014 coolo@suse.com
- fix license for spdx 1.2
* Fri Jul 18 2014 pgajdos@suse.com
- build against librsvg again
* Fri Jul 18 2014 pgajdos@suse.com
- updated to 6.8.9-5
  * Use -define profile:skip=icc, for example, to skip color profiles on read.
  * Do not let libpng16 check ICC/sRGB profiles in non-debug runs; we do it
    ourselves anyway. Avoids emitting "known incorrect profile" warnings.
    For strict profile checking and warning, use "-debug coder".
  * Disabled OpenCL acceleration when image has a 'mask' or 'clip-mask'.
* Wed Jun 25 2014 pgajdos@suse.com
- updated to 6.8.9-4
  * Support RMS argument for -evaluate-sequence and -statistic options.
  * Pipe image to display program no longer reports an exception.
  * Check that profile is non-NULL in coders/tiff.c.
* Tue Jun 10 2014 opensuse@dstoecker.de
- update to 6.8.9-3
  * Quiet warning about unused variable "skip_to_iend" in coders/png.c.
  * Fixed creation of SVG from 8bim clip path.
  * The -version option returns 0 status
  * The inline coder can now read from standard input
  * Add '=' character to the santize whitelist.
* Sat May 31 2014 opensuse@dstoecker.de
- update to 6.8.9-2
  * Fixed some bugs in the PNG codec discovered by coverity analysis.
  * The -fx equality operator returns a proper boolean result now.
  * Permit spaces in the gradient color specification.
  * Fix IdentifyImage() crash when image->magick member is null.
  * The -format M and Y channels are no longer reversed.
  * Remove Makefile race condition where two targets attempt to install
    magick-baseconfig.h
  * Fix memory leak in BlobToStringInfo().
  * In certain cases, -adaptive-sharpen failed to sharpen
  * Bump major Magick++ library version.
  * Added support for writing RLE compressed TGA files.
  * Improved performance of parsing the xmp profile.
  * Fixed detecting transparency in PSD files.
* Sat May 31 2014 coolo@suse.com
- remove autotrace dependency again - it's not compiled in and
  autotrace's last release is 10 years old and we don't want to
  promote it, better drop it
* Tue May 27 2014 opensuse@dstoecker.de
- update to 6.8.9
  * Fixed bug with the PNG00 subformat when the original format was PNG32.
  * The "-strip" option now only removes profiles and comments from PNG
    output.  Previously the background, density, and other metadata were
    also discarded.
  * Support new -hough-lines option.
  * Support new -mean-shift option.
  * identify -units without argument no longer faults (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=25542).
  * Require OpenJP2 version 2.1.0 (opj_stream_set_user_data() method signature
    change between 2.0.0 and 2.1.0).
* Sat May 24 2014 mailaender@opensuse.org
- Fixed the SLE build
- Added missing dependencies:
  * autotrace
  * dejavu-fonts
  * fftw3
  * ghostscript
  * libjbig
  * liblqr
  * mupdf
  * p7zip
  * xdg-utils
  * zip
* Thu Apr 24 2014 dmueller@suse.com
- remove dependency on gpg-offline (blocks rebuilds and
  tarball integrity is checked by source-validator anyway)
* Mon Mar  3 2014 pgajdos@suse.com
- directories in libMagickCore depends on %%{clibver} and
  %%{quantum_depth} [bnc#866442]
* Thu Feb 27 2014 pgajdos@suse.com
- fix baselibs
* Wed Feb 26 2014 opensuse@dstoecker.de
- update to 6.8.8-7
- remove disable_mat_test.patch (fixed upstream)
* Tue Feb 18 2014 pgajdos@suse.com
- updated to 6.8.8-6:
  * build against openjpeg2
  * identify -define identify:locate=maximum locates the position of the
    maximum value
  * Fix case where an image moment might have a mass of 0 or a Hu moment might
    be 0.
  * Enhance the TXT coder to read RGB percent values, e.g. 10.008%%.
  * etc. see ChangeLog
* Thu Feb 13 2014 pgajdos@suse.com
- modified patches [bnc#843673]:
  * disable_mat_test.patch -- rather than disable the test,
    use upstream solution (increase threshold for mean error)
  - - use this patch also for s390, s390x
* Wed Jan  8 2014 pgajdos@suse.com
- updated to 6.8.8-1:
  * Support points argument for draw MSL element.
  * The -page option now correctly sets the image page offset.
  * The -evaluate-sequence sum returns a proper alpha channel now.
  * etc. see ChangeLog
* Wed Jan  8 2014 coolo@suse.com
- really disable parallel build, don't just have a comment about it
* Wed Dec 18 2013 pgajdos@suse.com
- updated to 6.8.7-10:
  * fix crash when using -resize with GPU acceleration
* Mon Dec  9 2013 pgajdos@suse.com
- updated to 6.8.7-9:
  * fixed bug in coders/png.c that caused -define png:color-type=0
    to fail
  * fixed bug in automatic selection of OpenCL device
  * simplified interface to initialize the OpenCL environment
  * Fix possible memory corruption when writing PSD image
  * etc. see ChangeLog
* Mon Oct  7 2013 tom.mbrt@googlemail.com
- added openexr-devel as build requirement to enable openexr support
* Thu Oct  3 2013 pgajdos@suse.com
- use fdupes -s [bnc#841472]
* Wed Oct  2 2013 dvaleev@suse.com
- disable mat tests for powerpc bnc#843673 (disable_mat_test.patch)
* Wed Oct  2 2013 pgajdos@suse.com
- documentation back to -doc package (bnc#841472)
* Tue Oct  1 2013 coolo@suse.com
- fix baselibs.conf for previous change
* Mon Sep 30 2013 pgajdos@suse.com
- setting quantum depth to 16 [bnc#840825]
* Mon Sep 30 2013 pgajdos@suse.com
- fix build (find doesn't support -perm +mode)
* Thu Sep  5 2013 pgajdos@suse.com
- updated to 6.8.6-9
  * Fixed infinite loop with jpeg:extent.
  * Fixed performance issue when converting jpeg to png.
  * Added "-define bmp:format=bmp2|bmp3|bmp4" option.
  * etc. see ChangeLog
* Tue Aug  6 2013 pgajdos@suse.com
- updated to 6.8.6-7
  * Fix memory leak in CloneImageArtifacts and CloneImageProfiles.
  * JPEG ICC color profile requires null after ICC tag
  * etc.
- employ gpg-offline
* Mon Jun 17 2013 pgajdos@suse.com
- use AllCompliance instead of X11Compliance to cover also 'None'
  [bnc#825151]
  * adjusted no-XPMCompliance.patch
* Mon Jun  3 2013 pgajdos@suse.com
- mark no-XPMCompliance.patch as suse specific
  http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=23462
* Thu May 23 2013 pgajdos@suse.com
- workaround: fix reading xpm which uses symbolic color names which
  are said to be not XPMCompliant
  * http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=23462
* Tue May 21 2013 pgajdos@suse.com
- update to 6.8.5-7:
  * fixes reading XPM
* Mon May 13 2013 pgajdos@suse.com
- update to 6.8.5-6:
  * fixed 'Sometimes an sRGB image is masquerading as grayscale'
  * fixed 'The stream utility no longer faults when exporting float pixels'
  * Labels no longer overflow
  * Change the sample JPEG quantization table xml to something that works
    really well with 2x2 Chroma subsampling around quality 75.
  * Eliminate whitespace from image properties that hold PNG chunk data.
  * etc. see ChangeLog
- remove fix-wand.pc.patch, the issue is fixed upstream
- remove test-signatures.patch, the issue is fixed upstream
* Sun Apr  7 2013 coolo@suse.com
- add ImageMagick-6.8.4.0-fix-wand.pc.patch to fix build of e.g.
  emacs and xine-lib, who rely on pkg-config --libs Wand returning
  actually MagickWand and not MagickCore (looks like a copy&paste
  error of upstream)
* Fri Mar 29 2013 pgajdos@suse.com
- update to 6.8.4-0:
  * dropped ImageMagick-6.8.2.4-revert-r9087-montage-signatures.patch,
    issue is almost fixed -> new test-signatures.patch,
    see followups in
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=2&t=22479
  * created rpath.patch
  * created dont-build-in-install.patch
- upstream changes
  * Do not write zero-length TIFF tags
  * Do not split words for caption
  * The -blur, -guassian-blur, and -sharpen are now convenience methods
    for -morphology convolve.
  * etc. see ChangeLog
* Sun Mar 24 2013 coolo@suse.com
- fix baselibs.conf
* Wed Feb 20 2013 pgajdos@suse.com
- use versioned /etc/ImageMagick* to allow parallel installation
  of libMagickCore
* Wed Feb  6 2013 vjt@openssl.it
- name library packages after the new -QN library names (thanks dstoecker)
- depend on newer libtiff
* Wed Feb  6 2013 vjt@openssl.it
- fix missed variable expansion
* Wed Feb  6 2013 vjt@openssl.it
- use a quantum depth of 8 for our package, as we do not require
  that amount of precision, and we prefer faster conversions with
  less heap usage.
* Wed Feb  6 2013 vjt@openssl.it
- updated to 6.8.2.4
  * Update libver to 7
  * Dropped upstreamed ImageMagick-uninitialized-memory.patch
  * Added ImageMagick-6.8.2.4-revert-r9087-montage-signatures.patch
    Related to GhostScript. Discussion:
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=2&t=22479&p=95023
  * Add support for -QN library and .pc names, that express the
    pixel quantum depth the library was compiled with. Added an
    explicit spec variable for it
  * BuildRequire autoconf >= 2.69
* Tue Jan 15 2013 pgajdos@suse.com
- fix wrong mean-error output:
  http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=22586
  * dropped disable-matlab-test.patch
  * added ImageMagick-uninitialized-memory.patch
* Thu Jan 10 2013 meissner@suse.com
- do not disable checking altogether.
- disable-matlab-test.patch: disable the 1 MATLAB testcase that fails.
* Thu Jan 10 2013 mrdocs@opensuse.org
- disable check for the moment, it breaks on Factory and 12.1, but
  12.2
* Tue Jan  8 2013 schuetzm@gmx.net
- enable support for Pango markup
  * this allows rendering formatted text with the pango:"..." syntax
    see http://www.imagemagick.org/Usage/text/#pango for details
  * to actually use this, libpango needs to be installed
* Tue Aug  7 2012 pgajdos@suse.com
- updated to 6.7.8.8:
  * Added 2d named convolution kernel Binomial (for Fred Wienhaus)
  * Clean up sigmoidal-contrast.
  * Use ConcatenateString() for multi-block GIF comments.
  * Caption no longer chops off text (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=21558).
  * Support LUV colorspace.
  * Support HCL colorspace.
  * Don't transform the composite image colorspace, set it instead.
  * Interpret -border 5%% as 5%% of width and 5%% of height (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=21537).
  * Don't normalize zero-sum kernels (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=21584).
  * Transform grayscale to linear RGB if fill color is non-gray (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=21586).
  etc. see ChangeLog
* Wed May 16 2012 pgajdos@suse.com
- updated to 6.7.6.9:
  * Don't write an invalid PNG sRGB chunk when rendering intent is undefined.
  * EXR images are in the linear RGB colorspace with a gamma of 1.0.
  * Correct annotation offset for right-to-left labels.
  * The -level 100x0%% now produces the equivalent of -negate.
  * etc., see ChangeLog
* Tue Mar 27 2012 pgajdos@suse.com
- cleanup the package
- updated to 6.7.6.1: fixes
  * CVE-2012-0247 [bnc#746880]
  * CVE-2012-0248 [bnc#746880]
  * CVE-2012-1185 [bnc#752879]
  * CVE-2012-1186 [bnc#752879]
* Fri Mar  9 2012 giecrilj@stegny.2a.pl
- moved the libtool archives to the main package
- separated the bulk documentation
- added a regression %%check for the locale comma crash
* Tue Feb 14 2012 cfarrell@suse.com
- license update: SUSE-ImageMagick
  Use SUSE- proprietary prefix until SPDX upstream accepts ImageMagick as
  license (e.g. like Fedora)
* Thu Jan 19 2012 pgajdos@suse.com
- ImageMagick-devel requires libbz2-devel [bnc#741947]
* Thu Jan 19 2012 pgajdos@suse.com
- update to 6.7.4.7:
  * Fixed -black-threshold and -white-threshold so they work properly with
    the -channels option
  * Promote image depths 9-15 to 16 to avoid crashing in the PNG
    encoder
  * Fix problems with JNG encoder "quality"
  * Fix memory leak in JP2 coder
  * Use maximum bounds when rendering PDF
  * etc. see ChangeLog
* Tue Jan 17 2012 crrodriguez@opensuse.org
- Add explicit libbz2-devel BuildRequires
- Support LZMA
- Use libcms2 now.
- Cleanup huge dependency bloat in -devel package, this
  will likely cause build fails on dependant packages
  the solution is to fix your BuildRequires.
* Mon Oct 31 2011 pgajdos@suse.com
- update to 6.7.3.3:
  * removed upstreamed scene.patch
* Tue Oct 18 2011 pgajdos@suse.com
- build against librsvg as recommended upstream [bnc#724222]
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Thu Oct  6 2011 pgajdos@suse.com
- fixed [bnc#717871] -- imagemagick display wrong order
  * scene.patch
* Tue Sep 20 2011 pgajdos@suse.com
- update to 6.7.2.7:
  * Fix memory leak in text annotation.
  * The "-strip" option was excluding the PNG tRNS chunk.
  * Caption now wraps properly for Chinese text.
  * The PNG encoder would sometimes fail to respect the -define
    PNG:color-type option when the incoming image was PseudoClass.
  * Properly handled continued JPEG embedded profiles.
  * Revert -colorspace sRGB option patch.
  * Revert -type PaletteMatte option patch.
  * etc. see ChangeLog.
- obsoletes reason-error-message.patch
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Sep 16 2011 jengelh@medozas.de
- Fix baselibs: add missing requires to ImageMagick-devel
- Remove redundant tags/sections
* Wed Sep  7 2011 pgajdos@suse.com
- fixed wrong error messages [bnc#673303]
* Fri Jul 29 2011 pgajdos@novell.com
- update to 6.7.1.0:
  * Defend against corrupt PSD resource blocks.
  * Properly allocate points when render text with large font size.
  * Added support for Z_RLE strategy in the png compressor, using
  - quality 98 or 99.
  * Handle "-quality 97" properly in the png encoder, i.e., use intrapixel
    filtering when writing a MNG file and no filtering when writing a PNG file.
  * Added "-define PNG:compression-level|strategy|filter=value" options to
    the PNG encoder.  If these options are used, they take precedence over
    the -quality option.
  * Use zlib default compression strategy instead of Z_RLE and Z_FIXED
    strategies when linking with zlib versions (prior to 1.2.0 and 1.2.2.2,
    respectively) that don't support them.
- switch on WEBP support -- require libwebp-devel to build
* Mon Jun 20 2011 pgajdos@novell.com
- updated to 6.7.0.8:
  * added Initial implementation of Cylinder to/from Plane 3D Distorts
    Includes deritive (scaled lookup), and anti-alised horizon (validity)
    Currently can NOT handle extractions from full 360 cylinder panoramas.
  * Fix transient error for composite over operator.
  * Fix one-off bug in option parser.
  * etc., see ChangeLog
- adjusted inc-struct.diff
* Fri May 27 2011 coolo@novell.com
- fix requires of -devel package
* Thu May 26 2011 coolo@novell.com
- remove the -fuse-linker-plugin option, it's default in gcc 4.6
  and only confuses scripts
* Tue May 24 2011 dimstar@opensuse.org
- Require ImageMagick from -devel subpackage: Packages that depend
  on the -devel package very likely use the tools too.
* Tue May 17 2011 pgajdos@suse.cz
- updated to 6.6.9.9:
  * The -scale option nows considers the alpha channel when scaling.
  * Don't use comma as a separator for stroked tex.
  * Fix transient bug for HSL to RGB and back.
  * Fixed PNG8 reduction to work with an image that reduces to 256 colors
    plus transparency, by merging the two darkest red colors.
  * etc., see ChangeLog
* Sun May  8 2011 giecrilj@stegny.2a.pl
- created ImageMagick-devel-32bit for cross-compiling
* Thu Apr 21 2011 giecrilj@stegny.2a.pl
- updated to 6.6.9.5: fixes [Bug 682238]
  * macroized and cleaned up scripts
  * added conditions for optional components
  * updated file lists for upstream
  * cleaned up the include tree in devel (patch)
* Mon Apr 11 2011 pgajdos@suse.cz
- updated to 6.6.8.9: fixes [bnc#682238]
  * config files moved to /etc/ImageMagick*
  * see ChangeLog for more details
* Wed Feb 23 2011 pgajdos@suse.cz
- updated to 6.6.7.9: fixes [bnc#673789]
  * removed survive-exif.patch
* Mon Feb 21 2011 jw@novell.com
- added patch for crash reading png with exif
  [bnc#673789]
* Mon Feb 14 2011 pgajdos@suse.cz
- packaged README.txt from xtp [bnc#671047]
* Mon Dec  6 2010 coolo@novell.com
- fix build for factory
* Mon Nov 15 2010 pgajdos@suse.cz
- updated to 6.6.5-8: don't read config files from $CWD
  [bnc#653572]
* Thu Nov  4 2010 pgajdos@suse.cz
- updated to 6.6.5-5:
  * Revised PNG palette optimization
  * Added some debug logging in coders/png.c.
  * More precise blur values for Lanczos2Sharp and LanczosSharp.
  * Added location of first Mitchell crossing (=8/7) to the filters data
    structure.
  * Added Lanczos2D* filters now named Lanczos2*
  * Reorganization of AcquireFilter() to make it work better
  * Clearer EWA filters (LanczosSharp etc) comments.
  * Added LanczosSharp  (3-lobe Lanczos with sharpening)
  * Filter sharpening factors are also always applied regardless of usage.
  * CubicBC filter formulas simplified by constant folding. In
    particular, P1 coefficient (always zero) removed from coeff.
  * Revert the Robidoux filter to a Keys cubic with C=(108 sqrt 2-29)/398
    (as already specified in the documentation).
  * Ignore PS bounding box offsets if -page is set.
  * Add support for -evaluate exp.
* Fri Oct 15 2010 pgajdos@novell.com
- updated to 6.6.5-0:
  * Added "filter:sigma" expert setting defining the 'sigma' for the Gaussian
    filter only.  This is similar in action to 'blur' but only for Gaussians,
    and does not modify the filters support, allowing you to set a very small
    sigma, without the function 'missing' all pixels.
  * Patch for  DrawableRotation() and DrawableTranslation()
  * The webp format requires the webpconv delegate program (experimental).
  * Replaced "Robidoux" with Cubic 'Keys' filter that is near equivelent to
    the previous sharped "Lanczos2D" filter. (C=0.31089212245300069)
    This also is very similer to a Mitchell filter but specifically designed
    for EWA use and is the new default filter for Distorting Images.
  * Added new filter 'Lanczos2D' a 2-lobe Lanczos as defined by
    Andreas Gustafsson in his thesis  "Interactive Image Warping" (page 24)
    http://www.gson.org/thesis/warping-thesis.pdf
  * Added filter "Robidoux" which is a slightly sharpened version of the
    "Lanczos2D" filter (blur=0.958033808) specifically designed to be less
    'blurry' for horizontal and vertical lines in no-op distortions.
  * Add support for "pattern:vertical2" and "pattern:horizontal2".
  * Add support for "pattern:vertical3" and "pattern:horizontal3".
  * Properly handle PSD layers with negative offsets.
  * Added sqrt(2) bluring default for Gaussian Filter if used as
    a Cylindrical EWA filter.  This resulted removing the last aliasing
    issue that was present in tests for Gaussian EWA resampling. Of course
    it is still a very blury filter for default use in EWA.
  * Adjusted Variable Mapping Blur Composition so user arguments actual
    relate properly to the sigma of the blur for a maximum mapping value.
  * Fix horizon anti-alising for output-scaled perspective distortions.
  * 'Bessel' filter is now offically and more accuritally named 'Jinc'
    however 'Bessel' while not visible as a filter option can still be used
    as an internal alias for 'Jinc'.
  * Fix memory assertion with --enable-embeddable (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=17201).
  * Don't permit access to pixels when pinging an image (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=17194).
* Tue Oct  5 2010 pgajdos@novell.com
- updated to 6.6.4-8:
  * Automatically set the quantum depth to 16 for HDRI.
  * IPTC profile not always wrapped properly inside an 8BIM profile.
  * TIFF tile geometry must be divisible by 16.
  * Rename of SincPolynomial to SincFast for easier user understanding.
    Ditto for LanczosChebyshev to LanzcosFast.
  * Switch default resize filters to using the faster SincPolynomial
    filter by default internally.  However 'Sinc' will still use the
    Trigonometric function, and can be used to assign the trig version
    of Sinc() to filters using the filter expert options.
  * The default filter for 'distort' was found to be a very blurry inaccurate
    filter function.  It was removed and replaced with a correct Gaussian
    filter (as used by resize)
  * Added a switch so that "-interpolate filter" will force the use of
    a cylindrical filter for ALL pixels in distorted images.  That is you can
    use that switch to use a cylindrical filter even for images that are
    being enlarged by the distortion.  However EWA is still currently using
    a fixed 2.0 sampling radius.  This switch complements the use of "-filter
    point" which turns off EWA filters in favor of interpolation for all
    pixels in a distorted image.  BOTH switches should not be used together.
  * A bug in the support radius of the EWA resampling function was found,
    now that correctly defined resize filters are being used. Suddenly Normal
    Gaussian distortions are not so blurry, and tests with distortions of
    the 'Rings' image show extremely good and clear results, with only minimal
    blurring.  The filter 'blur' expert option can be used to adjust this
    further.
  * Don't negate the geometry offset for the -extent option.
  * The RGBO format is now listed as a supported format.
  * Added the Nicolas Robidoux and Chantal Racette  Lanczos resize filter
    function as "LanczosChebyshev" as faster alternative to Lanczos.
  * Re-code Nicolas Robidoux and Chantal Racette Polynomial Approximation of
    the Sinc Trigonometric resize filter, as a proper filter to allow
    direct comparision and speed testing of the filter.
  * Expanded the "-set option:filter:verbose 1" output, so as to also include
    the actual functions and other values that were used to create the filter.
* Tue Sep  7 2010 pgajdos@suse.cz
- updated to 6.6.4-0:
  * Repair a few incorrect LocaleNCompare() calls (ttf.c, ps.c).
  * Path no longer closed if join style is round (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16943).
  * Add case for BGRQuantum to GetQuantumExtent().
  * Support no compression on PCX write.
  * Fixed bug in the raw BGRA coders (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16880).
  * Fix off-by-one error in the PSD coders.
  * Nicolas Robidoux with the assistance of Chantal Racette contribute an
    approximation of the sinc function over the interval [-3,3].
  * Eliminate a small memory leak in LevelizeImageChannel() (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16951).
  * Recognize -fx logtwo (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16958).
* Tue Aug 24 2010 pgajdos@suse.cz
- updated to 6.6.3-9:
  * Eliminate useless message about assuming zero delay when writing
    a single-frame MNG, and changed it from Error to Warning when
    writing a multiple-frame MNG.
  * Only use the first alpha channel in PSD image.
  * Only use XPM complying colors for XPM images (e.g. green is rgb(0,255,0)).
  * Eliminate bogus "invalid colormap index" when pinging ICO images.
  * Support -set density / units.
  * Properly map PNG intent to image->rendering_intent
  * The orient option sometimes improperly set "undefined" (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16795).
  * Only list orientation options for the -list orientation option (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16801).
  * Return proper standard deviation for combined channels (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16786).
  * Handle transparency properly for the PSD image format.
  * Emit a warning if the PNG encoder can't satisfy the color type and
    bit depth requested with a "-define" directive.
  * The -fx 2e+6/1e+5 argument no longer returns the wrong results (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=16833).
  * Add -subimage-search option to the compare utility.
  * Throw exception if image size differs for the compare program but the
  - subimage-search option is not specified.
* Mon Aug  2 2010 coolo@novell.com
- update baselibs.conf
* Thu Jul 29 2010 pgajdos@suse.cz
- updated to 6.6.3-1:
  * obsoletes units.patch
  * obsoletes grayscale-tiff-jpeg.patch
* Tue Jun 22 2010 pgajdos@suse.cz
- fixed jpeg compression of grayscale tif format [bnc#615223]
* Mon May 10 2010 aj@suse.de
- Do not compile in build time but use mtime of changes file instead.
  This allows build-compare to identify that no changes have happened.
* Mon Apr 26 2010 pgajdos@suse.cz
- fixed units in the output [bnc#598714]
  * units.patch
* Wed Apr  7 2010 ro@suse.de
- update baselibs.conf
* Tue Apr  6 2010 pgajdos@suse.cz
- updated to version 6.6.1-0:
  * Fixed bug in equal-size tile cropping, when image has a page offset.
  * The -recolor 4x4 matrix is now interpretted properly (previously it
    summed rather attenuating the alpha channel).
  * Support writing 1-bit PSD images.
  * Support LCMS 2.0.
  * Improved WMF support under Windows.
  * The new coders/png.c was failing to read a 1-bit paletted image properly.
  * Finished eliminating the deprecated direct references to members of
    the png_info structure. ImageMagick can now be built with libpng-1.5.
  * Respect the -density option when rendering a Postscript or PDF image.
  * Distort barrel no longer complains when 3 arguments are given (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=15883).
  * Support -direction left-to-right option for rendering text
  * coders/png.c: Eliminated support of libpng versions older than 1.0.12.
  * Relocated the new, misplaced png_get_rowbytes() call.
  * Updated setjmp/longjmp/jmpbuf usage to work with libpng-1.5.
  * Add support for monochrome PSD images.
  * VignetteImage() no longer crashes when x and y arguments are both greater
    than half the width (x) and height (y) of the image.
  * Eliminated some of the deprecated direct references to members of
    the png_info structure.  This must be finished before we can build
    with libpng-1.5.
  * The animate program no longer loops twice when -loop 1 is specified.
  * The caption format would sometimes hang when the text was not UTF-8.
  * Don't gamma correct log to linear color conversion unless the -gamma is
    specified (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=1&t=15799).
  * Detect CMYKProcessColor AI tag.
  * Delete image from command line cache for -write option.
  * Add support for the Adobe Large Document format.
  * Recognize -remap option for the mogrify utility.
  * The default Helvetica font is not always available, check for
    Century Schoolbook too (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=2&t=15780).
* Mon Mar 15 2010 pgajdos@suse.cz
- updated to version 6.6.0-5:
  * Permit user to get virtual pixels with a region width of 0.
  * Reformulate the jinc() functio  so that the main peak is of amplitude of 1.
  * Resampling filter must respect the image virtual pixel method.
  * The -evaluate-sequence option behaves like -evaluate except it operates
    on a sequence of images.
  * Add support for the Adobe Large Document format.
  * Add support for the -maximum and -minimum options.
  * Check to see if ICON image width /height exceeds that of the image canvas.
  * Set the DPX descriptor to Luma only if the image type is not TrueColor.
  * Add support for -fx airy(), j0(), j1(), jinc(), and sinc() (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=2&t=15685).
  * Don't embed an XMP profile in an EPS image for now.
  * Insufficient image data in EPT is a warning rather than an error.
  * Respect -type TrueColor when writing gray DPX images.
  * Fix problem reading 10-bit grayscale DPX images when scanline length is
    not a multiple of 3.
  * BMP has an alpha channel, it was treated as an opacity channel.
  * Write 10-bit grayscale DPX images properly.
  * Detect PDF ICCBased colorspace.
  * Finalized -set option:convolve:scale  kernel normalize/scale option
  * TransformImage() resets the image blob when called in the PICT decoder;
    use SetImageExtent() instead.
  * Support PSD RLE compression.
  * The jpeg:extent define sometimes exceeded the specified limit.
  * Resolve "too many open files"  (reference
    http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=15546).
  * Added Correlate method which does a Convolve without reflecting the kernel.
  * Initialize grayscale colormap for PSD images.
  * Addition Third-level Subtractive Morphology Methods:
    EdgeIn, EdgeOut, Edge, TopHat, BottomHat
  * Ensuring original kernels passed to morphology are cloned before being
    modifified for use by specific methods (EG: convolve scale/normalize)
  * display -immutable to display transparent image without a checkboard.
  * Make -define png:color-type less persnickity about what it will accept.
  * added use of -precision in 'showkernel' output of -morphology
  * correct use of a 'reflected kernel' for 'Convolve' 'Dilate' and
    'Distance' Morphology primatives. This does not have a performance hit,
    though is only truely applicable when the kernel is asymmetric.  Note that
    'Erode' does not use a 'reflected' kernel, so that 'Open' and 'Close'
    operations work properly.  This 'reflected usage is defined by online
    morphology lecture notes (Google for "EECE Binary Morphology")
  * Added convolve kernel scaling setting "-set option:convolve:scale N"
    If undefined morphology convolve does not do any scaling or normalization
    of the convolution kernel.  A value of 0.0 causes normalization for both
    zero and non-zero (added weights) kernel types.
  * Speed up reading the PSD image format.
  * Add the -precision option.  Use it to set the maximum number of significant
    digits to be printed.
  * Add -features option to the identify program to display channel features.
  * Add -unique option to the identify program to display channel features.
  * Add support for compact floating point (i.e. -depth 16 -define
    quantum:format=floating-point).
  * Transparent images no longer flicker on certain system when using the
    display program.
  * Permit interactive resizing with the display program.
  * Support heterogeneous distributed processing, see
    http://www.imagemagick.org/script/architecture.php#distributed.
  * Fix semaphore assertion when reading a corrupt image with Magick++.
  * Add support for -brightness-contrast option.
  * Add support for the BGRA raw image format.
  * Added Kernel Generator to generate kernels from user strings, which
    allows the generation in many built in kernels for both Convolution
    and other Morphological methods.  New Kernels currently include..
    Convolution: Gaussian, Blur, Comet
    Morphological: Rectangle, Square, Diamond, Disk, Plus
    Distance: Chebyshev, Manhatten, Knight, Euclidean
    And both old and new (rectangular) user defined kernel specifications
    including the use of 'nan' to represent elements which are not part
    of the kernel definition.  List built-in kernel types use "-list kernel"
  * Added -morphology {method}[:{iteration}] {kernel_string}
    Initial methods includes no only the basic morphology methods: Dilate,
    Erode, Open, Close; and a pixel color preserving 'Intensity' version, but
    also the special methods: Convolve, and Distance.  Of course the
    appropriate kernel should be provided for each specific method.
  * Add OpenCL-enabled filter (e.g.  convert image.png -process
    "convolve '-1, -1, -1, -1, 9, -1, -1, -1, -1'" image.jpg).
  * Added StringTo...() processing functions
* Mon Feb 15 2010 pgajdos@suse.cz
- don't remove *.la files, see [bnc#579798]
* Tue Feb  9 2010 prusnak@suse.cz
- build -doc subpackage as noarch
- spec cleanup
* Mon Jan 11 2010 pgajdos@suse.cz
- updated to 6.5.8-9, which fixes [bnc#565014]
* Wed Jan  6 2010 jengelh@medozas.de
- package baselibs.conf
* Mon Nov 23 2009 pgajdos@suse.cz
- updated to 6.5.7-9 (See ChangeLog)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Aug 24 2009 pgajdos@suse.cz
- splitted out doc package, see [bnc#533439]
* Tue Aug  4 2009 pgajdos@suse.cz
- updated to version 6.5.4-8 (See ChangeLog)
* Thu Jul 30 2009 ro@suse.de
- update baselibs.conf to complete previous change
* Fri Jun  5 2009 nadvornik@suse.cz
- updated to 6.5.3-2:
  * shared library version increased from 1 to 2
  * subpackages renamed accordingly
  * includes a fix for bnc#507728
* Fri Jan 23 2009 nadvornik@suse.cz
- backported fix for race condition [bnc#465967]
* Fri Dec  5 2008 nadvornik@suse.cz
- fixed fontconfig detection [bnc#441874]
* Mon Dec  1 2008 ro@suse.de
- add libMagicWand1 to baselibs.conf (for libxine1)
* Tue Oct  7 2008 thoenig@suse.de
- add baselibs.conf (libMagickCore1) required by libfprint0-32bit
* Wed Sep 10 2008 nadvornik@suse.cz
- update to 6.4.3-6, see ChangeLog for details
* Wed Apr  9 2008 nadvornik@suse.cz
- update to 6.4.0-4, see ChangeLog for details
  * mostly bugfixes
* Mon Apr  7 2008 schwab@suse.de
- Fix PRNG.
* Sat Mar 29 2008 coolo@suse.de
- fix requires
* Wed Mar 26 2008 nadvornik@suse.cz
- updated to 6.3.9-7, see ChangeLog for details
  * renamed shared library subpackages:
    libMagick10 -> libMagickCore1
    libWand10 -> libMagickWand1
    libMagick++10 -> libMagick++1
  * read EXIF data in TIFF images
  * add -encipher / -decipher options to the command-line utilities
  * many bugfixes and improvements
* Mon Dec  3 2007 nadvornik@suse.cz
- fixed BuildRequires
* Fri Nov 30 2007 nadvornik@suse.cz
- updated to 6.3.7-2, see ChangeLog for details
  * fixes conflicts in header files [#340485]
* Mon Oct  8 2007 pth@suse.de
- Add libMagick10 to Requires of perl-PerlMagick (#331611)
* Tue Sep 25 2007 nadvornik@suse.cz
- updated to 6.3.5-10: fixes CVE-2007-4985, CVE-2007-4986,
  CVE-2007-4987, CVE-2007-4988 [#327021]
* Fri Aug  3 2007 coolo@suse.de
- fix provides for ImageMagick-Magick++ (#293401)
* Sat Jul 28 2007 coolo@suse.de
- remove requires on ImageMagick-Magick++
* Wed Jul 25 2007 nadvornik@suse.cz
- updated to 6.3.5-3, see ChangeLog for details
- reduced the requrements of the main package,
  created ImageMagick-extra with full set of requirements
- adjusted to Shared Library Policy:
  * created libMagick10 and libWand10
  * renamed ImageMagick-Magick++ -> libMagick++10
  * renamed ImageMagick-Magick++-devel -> libMagick++-devel
* Thu Apr 19 2007 nadvornik@suse.cz
- updated to 6.3.3-8, see ChangeLog for details
- fixed various crashes on malformed input, including
  CVE-2007-1797 and CVE-2007-1667 [#258253]
- do not build static libs
- adjusted BuildRequires for libjasper-devel
* Tue Feb 27 2007 dmueller@suse.de
- adjust BuildRequires: libexif -> libexif-devel
* Mon Feb 19 2007 mvaner@suse.cz
- Array boundaries fix in bezier path (#243280)
  - bezier-array.patch
* Mon Oct 30 2006 nadvornik@suse.cz
- fixed overflows in dcm and palm codecs CVE-2006-5456 [#215685]
* Wed Oct 18 2006 postadal@suse.cz
- disabled -fstack-protector for %%suse_version <= 1000
* Tue Oct 17 2006 nadvornik@suse.cz
- updated to 1.3.0-0
  * enhanced -fx
  * many bugfixes, see ChangeLog
* Thu Jul 13 2006 nadvornik@suse.cz
- updated to 1.2.8-1
  * security fixes merged upstream
  * fixed compilation with new libpng
  * many other fixes
* Wed Mar 15 2006 nadvornik@suse.cz
- fixed rpath in perl module
* Fri Feb  3 2006 nadvornik@suse.cz
- better fix for format string vulnerability
  CVE-2006-0082 [#141390]
- fixed shell metacharacters in file names passed into delegates
  CVE-2005-4601 [#141999]
- added version numbers to devel subpackage requirements
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 meissner@suse.de
- Use -fstack-protector.
* Tue Dec 20 2005 nadvornik@suse.cz
- updated to 6.2.5
* Wed Sep 21 2005 nadvornik@suse.cz
- updated to 6.2.4
* Sun Sep 18 2005 postadal@suse.cz
- parallelize build
* Wed Sep  7 2005 nadvornik@suse.cz
- fixed URL in man pages [#115568]
* Thu Jul 21 2005 nadvornik@suse.cz
- moved .la files back to main package, they are needed for runtime
* Fri Jul 15 2005 nadvornik@suse.cz
- updated to 6.2.3
- fixed incorrect char type usage [#95086]
* Tue May  3 2005 nadvornik@suse.cz
- updated to 6.2.2, fixes crash in PNM reader [#80428]
* Wed Mar  9 2005 nadvornik@suse.cz
- fixed format string vulnerability [#67273]
* Wed Mar  2 2005 nadvornik@suse.cz
- linked PerlMagick correcly
- added xorg-x11-devel to requires of devel subpackage
* Sat Jan 22 2005 ro@suse.de
- fix libltdl removal on lib64
* Tue Jan 18 2005 nadvornik@suse.cz
- updated to 6.1.8
  * fixed .psd file read overflow (CAN-2005-0005) [#49839]
* Mon Nov  1 2004 nadvornik@suse.cz
- fixed integer overflow in EXIF handling [#47745]
* Tue Sep 14 2004 nadvornik@suse.cz
- branched new subpackage ImageMagick-Magick++-devel [#45245]
* Tue Sep 14 2004 nadvornik@suse.cz
- removed Requires: ImageMagick-devel from ImageMagick-Magick++ [#45245]
* Tue Sep  7 2004 nadvornik@suse.cz
- updated to 6.0.7
  * fixed possible miscompilation of included headers
  * fixed PerlMagick's Profile crash [#44710]
  * other bugfixes
* Tue Aug 31 2004 nadvornik@suse.cz
- updated to 6.0.6-2:
  * fixed decoding runlength-encoded BMP [#44081]
  * enabled LZW compression
* Mon Aug  9 2004 ro@suse.de
- fix build with current automake
* Mon Jun 28 2004 nadvornik@suse.cz
- updated to 6.0.2
* Fri Mar 26 2004 nadvornik@suse.cz
- adjusted default fonts
* Fri Feb  6 2004 nadvornik@suse.cz
- update to 5.5.7-16
- added run_ldconfig macro
- build as user
* Tue Sep  9 2003 nadvornik@suse.cz
- fixed annotate function [29748]
* Mon Sep  8 2003 nadvornik@suse.cz
- fixed reading of tiff images [#25552]
* Thu Aug 28 2003 nadvornik@suse.cz
- fixed output from Magick++-config --version
- compiled with -fno-strict-aliasing
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 29 2003 nadvornik@suse.cz
- lib64 fixed
- filelist fixed
* Fri Jul 25 2003 nadvornik@suse.cz
- updated to 5.5.7-10
- used perl_process_packlist
* Mon Feb 10 2003 nadvornik@suse.cz
- updated to 5.5.4-4:
  - fixed bug [#23111]
- copied ltdl sources from libtool package
* Thu Dec 19 2002 adrian@suse.de
- add liblcms-devel to #neededforbuild
* Thu Nov 21 2002 nadvornik@suse.cz
- updated to 5.5.1
* Wed Nov 20 2002 ro@suse.de
- fix build with latest automake
* Fri Nov  1 2002 nadvornik@suse.cz
- fixed detection of lpr [#21187]
- fixed to compile with new libjasper
* Tue Sep  3 2002 nadvornik@suse.cz
- do not try to detect supported ghostscript devices [#18424]
* Thu Aug 29 2002 nadvornik@suse.cz
- fixed typo in delegates.mgk
* Sat Aug 10 2002 kukuk@suse.de
- Fix filelist for threaded perl
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri Jul 26 2002 nadvornik@suse.cz
- update to 5.4.7-4
* Tue Jul  2 2002 nadvornik@suse.cz
- update to 5.4.7
* Fri May  3 2002 meissner@suse.de
- %%_lib fixes
* Wed Mar  6 2002 nadvornik@suse.cz
- added symlink index.html->ImageMagick.html in doc directory
* Mon Feb  4 2002 nadvornik@suse.cz
- update to 5.4.2-3, xtp updated to 5.4.3
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 17 2002 nadvornik@suse.cz
- html files installed correctly
* Tue Jan 15 2002 nadvornik@suse.cz
- update to 5.4.2:
  - new scripting language utility, conjure
* Mon Dec  3 2001 nadvornik@suse.cz
- update to 5.4.1:
  - better SVG support
  - changed default background color to none
  - eliminated the libMagick.so dependancy on libtiff, libpng, libjpeg
  - coders/wmf.c updated for libwmf 0.2
* Thu Oct 18 2001 nadvornik@suse.cz
- update to 5.4.0:
  - Text drawing now handles UTF8-encoding
  - Added a MATLAB encoder
  - Uses SHA instead of MD5 for image signatures
* Fri Aug 24 2001 nadvornik@suse.cz
- update to 5.3.8:
  - Added a new method SetImageClipMask().
  - Added @ to the image geometry specification. Use it to specify
    the square-root of the maximum area in pixels of an image
  - many bugfixes
* Tue Aug 21 2001 nadvornik@suse.cz
- removed wv-devel from neededforbuild, it is no longer needed
- fixed segfault in svg converting
- fixed doc installation
* Wed Aug 15 2001 nadvornik@suse.cz
- compiled with libjasper
* Tue Jul 24 2001 nadvornik@suse.cz
- update to 5.3.7
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonto> to <ghostscript-fonts-other>
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_serv> to <ghostscript-serv>
* Wed Jun 27 2001 nadvornik@suse.cz
- update to 5.3.6
- dropped ImageMagick-pictures subpackage
* Tue Jun 12 2001 nadvornik@suse.cz
- update to 5.3.5
- fixed to compile with new autoconf
* Tue Apr 17 2001 kukuk@suse.de
- Remove magickcpp_version macro
* Thu Apr  5 2001 nadvornik@suse.cz
- updated to 5.3.1
* Tue Mar 27 2001 ro@suse.de
- libtoolize main dir as well
* Tue Mar 27 2001 ro@suse.de
- libtoolize
* Fri Mar  9 2001 nadvornik@suse.cz
- updated to 5.3.0
- fixed neededforbuild
* Mon Feb 19 2001 nadvornik@suse.cz
- fixed filelist
* Tue Feb 13 2001 nadvornik@suse.cz
- update to 5.2.9
* Tue Dec 12 2000 nadvornik@suse.cz
- compiled with option --with-threads
* Tue Dec  5 2000 nadvornik@suse.cz
- update to 5.2.6
- now uses freetype2
* Thu Nov 16 2000 nadvornik@suse.cz
- update to 5.2.5
* Tue Nov 14 2000 nadvornik@suse.cz
- fixed writing transparent xpm files
* Wed Nov  8 2000 nadvornik@suse.cz
- changed to long names
-    imagemag -> ImageMagick
-    magickd  -> ImageMagick-devel
-    magickpp -> ImageMagick-Magick++
-    plmagick -> perl-PerlMagick
-    impict   -> ImageMagick-pictures
* Wed Oct 18 2000 nadvornik@suse.cz
- update to 5.2.4
- compiled with --with-modules
* Mon Sep 18 2000 nadvornik@suse.cz
- fixed usage of suse_update_config
* Thu Sep 14 2000 nadvornik@suse.cz
- drop subpackage imfilm, removed povray from neededforbuild
- povray scripts are now in /usr/share/doc/imagemag/scenes
* Thu Sep 14 2000 nadvornik@suse.cz
- update to 5.2.3
- new subpackage magickd for includes and static libs
- changed prefix to /usr
- removed --without-largefiles
* Wed Aug 23 2000 ro@suse.de
- fixed perl path
* Thu Jun  8 2000 nadvornik@suse.cz
- update to latest source from ftp
- added source url
* Tue Jun  6 2000 nadvornik@suse.cz
- images, scenes -> /usr/share/ImageMagick
- doc -> %%{_defaultdocdir}/imagemag
* Mon Jun  5 2000 nadvornik@suse.cz
- used --without-largefiles
* Thu Jun  1 2000 nadvornik@suse.cz
- xtp updated to 5.2.0
* Mon May 29 2000 nadvornik@suse.cz
- updated to 5.2.0
* Fri May 19 2000 nadvornik@suse.cz
- used %%{_defaultdocdir}
- changed group
* Fri Apr 28 2000 nadvornik@suse.cz
- fixed to compile with xf86-4.0
* Mon Apr 10 2000 nadvornik@suse.cz
- added URL
* Fri Apr  7 2000 bk@suse.de
- added suse config update macro
* Thu Apr  6 2000 nadvornik@suse.cz
- update to 5.1.1
- added BuildRoot
* Wed Jan 19 2000 ro@suse.de
- fixed specfile
* Mon Jan  3 2000 ro@suse.de
- update to 5.1.0
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  2 1999 ro@suse.de
- update to 4.2.9
* Mon Jun 28 1999 ro@suse.de
- update to 4.2.7
* Wed May 19 1999 ro@suse.de
- fixed path in specfile
* Wed May 19 1999 ro@suse.de
- fixed specfile
* Wed May 19 1999 ro@suse.de
- update to 4.2.5
- new subpackage: magickpp (aka Magick++) a C++-API for libmagick
* Fri Feb 19 1999 ro@suse.de
- update to 4.2.0
* Mon Jan 18 1999 bs@suse.de
- set libraries to 755
* Wed Jan 13 1999 ro@suse.de
- update to 4.1.7 / PerlMagick 1.58
* Mon Dec 14 1998 ro@suse.de
- update to 4.1.6
- disabled unix98/ptys in configure.in
* Tue Dec  1 1998 ro@suse.de
- update to 4.1.5 / PerlMagick 1.53
* Tue Nov 17 1998 ro@suse.de
- update to 4.1.4
- switched to use configure instead of imake
* Mon Aug 17 1998 ro@suse.de
- update to 4.0.9
* Fri Aug 14 1998 ro@suse.de
- fixed online documentation
  /usr/doc/packages/ImageMagick/ImageMagick.html is start page
- added new subpackage PerlMagick "plmagick"
* Thu Aug 13 1998 ro@suse.de
- update to 4.0.8
  fixed default for printCommand in Display with a app-defaults file
* Mon Jun 29 1998 ro@suse.de
- update to version 4.0.7
  needs libpng-1.0.1 (and povray built with that version)
* Tue Apr  7 1998 ro@suse.de
- update to version 4.0.4
  added freetype support
  needs libpng-1.0.1 (and povray built with that version)
* Sun Mar  1 1998 ro@suse.de
- update to version 4.0.1
* Sun Nov 16 1997 ro@suse.de
- fixed Symlink /usr/doc/packages/ImageMagick
* Fri Nov 14 1997 ro@suse.de
- new version 3.9.2
* Tue Nov 11 1997 ro@suse.de
- imfilm and impict are built from same specfile
* Mon Nov  3 1997 ro@suse.de
- ready for autobuild
